Top

    Poison the Well of Life
    Stockholm, Sweden
    October 29th 2011
    2R+F
    19 players
    Marcus Berg

    Deck Name: Yet another Imbued deck winning a tournament
    Description: Too many cards, should be slimmed about 15 cards.
    All Enchant Kindred should be Entrancement. One or both Kiss of
    Ra should be Mind Numb. Villein and Lilith's Blessing should be
    2 Blood Doll and 2 Vessel. Should maybe add 2-4 Majesty. Crypt
    should be 4 Mary Anne Blaire, 2 Lodin and the rest singles.

    Crypt (12 cards, min=17, max=36, avg=6.75)
    ------------------------------------------
    2x Mary Anne Blaire	10  AUS DOM FOR PRE ani pot	justicar  Ventrue:5
    2x Epikasta Rigatos	8   AUS DOM PRE cel		prince	  Toreador:4
    2x Lodin (Olaf Holte)	8   DOM FOR PRE aus pro		prince	  Ventrue:5
    2x Victor Donaldson	6   DOM for pre			prince	  Ventrue:5
    2x Emily Carson		5   DOM for pre			primogen  Ventrue:5
    1x Maman Boumba		4   inn mar				  Martyr:4
    1x Keith Moody		3   DOM					  Tremere antitribu:4

    Library (90)
    Action [21]
    4x Enchant Kindred
    15x Govern the Unaligned
    2x Mind Numb

    Action Modifier [13]
    3x Conditioning
    1x Daring the Dawn
    7x Freak Drive
    2x Kiss of Ra, The

    Action Modifier/Reaction [6]
    6x Murmur of the False Will

    Ally [1]
    1x Carlton Van Wyk (Hunter)

    Conviction [1]
    1x React with Conviction

    Equipment [1]
    1x Heart of Nizchetus

    Master [19]
    1x Anarch Troublemaker
    4x Dreams of the Sphinx
    1x Giant's Blood
    1x Information Highway
    1x Lilith's Blessing
    1x Misdirection
    2x Pentex(TM) Subversion
    6x Villein
    2x Wider View

    Political Action [2]
    1x Banishment
    1x Parity Shift

    Reaction [26]
    7x Deflection
    3x Eyes of Argus
    8x Obedience
    8x Second Tradition: Domain